==> reference_cmsplugin-0.2.0.tar.gz: reference_cmsplugin-0.2.0/reference_cmsplugin/cms_plugins.py <==
# -*- coding: utf-8 -*-

from django import forms
from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .models import (
    Reference,
    ReferencePlugin as ReferencePluginModel,
    Category,
)


class ReferencePluginModelForm(forms.ModelForm):
    categories = ReferencePluginModel._meta.get_field('categories').formfield(
        help_text=_('Select a list of categories to display, or none to show them all.'),
    )

    class Meta:
        model = ReferencePluginModel
        fields = [
            'categories',
        ]


class ReferencePlugin(CMSPluginBase):
    model = ReferencePluginModel
    name = _('Reference plugin')
    render_template = 'reference_cmsplugin/reference_list.html'
    form = ReferencePluginModelForm
    cache = True

    def render(self, context, instance, placeholder):
        if instance.categories.count():
            categories = instance.categories.enabled()
            references = Reference.objects.enabled().filter(
                categories__in=instance.categories.enabled(),
            ).distinct()
        else:
            categories = Category.objects.enabled()
            references = Reference.objects.enabled()

        context.update({
            'instance': instance,
            'categories': categories.order_by('-order'),
            'references': references.order_by('-order'),
        })
        return context


plugin_pool.register_plugin(ReferencePlugin)

==> reference_cmsplugin-0.3.1.tar.gz: reference_cmsplugin-0.3.1/reference_cmsplugin/cms_plugins.py <==
# -*- coding: utf-8 -*-

from django import forms
from django.utils.translation import ugettext_lazy as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from .models import (
    Reference,
    ReferencePlugin as ReferencePluginModel,
    Category,
)


class ReferencePluginModelForm(forms.ModelForm):
    categories = ReferencePluginModel._meta.get_field('categories').formfield(
        help_text=_('Select a list of categories to display, or none to show them all.'),
    )

    class Meta:
        model = ReferencePluginModel
        fields = [
            'categories',
        ]


class ReferencePlugin(CMSPluginBase):
    model = ReferencePluginModel
    name = _('Reference plugin')
    render_template = 'reference_cmsplugin/reference_list.html'
    form = ReferencePluginModelForm
    cache = True

    def render(self, context, instance, placeholder):
        if instance.categories.count():
            categories = instance.categories.enabled()
            references = Reference.objects.enabled().filter(
                categories__in=instance.categories.enabled(),
            ).distinct()
        else:
            categories = Category.objects.enabled()
            references = Reference.objects.enabled()

        context.update({
            'instance': instance,
            'categories': categories.order_by('order'),
            'references': references.order_by('order'),
        })
        return context


plugin_pool.register_plugin(ReferencePlugin)
